==> haskell-semialign-1.3-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semialign.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semialign
version:              1.3
visibility:           public
id:                   semialign-1.3-Iq9uPIQm2d78SODEZXukog
key:                  semialign-1.3-Iq9uPIQm2d78SODEZXukog
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:
    Align and Zip type-classes from the common Semialign ancestor.

description:
    The major use of @These@ of this is provided by the @align@ member of
    @Semialign@ class, representing a generalized notion of "zipping with padding"
    that combines structures without truncating to the size of the smaller input.

    It turns out that @zip@ operation fits well the @Semialign@ class,
    forming lattice-like structure.

category:             Data, These
abi:                  6c826dad81a4cadd74fe8f1966377365
exposed:              True
exposed-modules:
    Data.Align Data.Crosswalk Data.Semialign Data.Semialign.Indexed
    Data.Zip

hidden-modules:       Data.Semialign.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/semialign-1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/semialign-1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/semialign-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semialign
hs-libraries:         HSsemialign-1.3-Iq9uPIQm2d78SODEZXukog
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-D3M5e9EeJxCJTqzfO7ugwa
    indexed-traversable-0.1.4-DOGxrFcaLiiKO9QlCmrhlX
    indexed-traversable-instances-0.1.2-129mrEmT4RMG5J8h5kEQbE
    semigroupoids-6.0.1-JkwKDZ0CHrJBmm8BH5uGyt
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    these-1.2.1-EbXrHb0haEd5djHK7Kp4Y4 transformers-0.5.6.2
    unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W
    vector-0.13.2.0-G0g5gCprguQ6M58H7uQE53

haddock-interfaces:   /usr/share/doc/haskell-semialign/html/semialign.haddock
haddock-html:         /usr/share/doc/haskell-semialign/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semialign-1.3-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semialign.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semialign
version:              1.3
visibility:           public
id:                   semialign-1.3-BEOiTXTzJKR2MDDBEuAs8X
key:                  semialign-1.3-BEOiTXTzJKR2MDDBEuAs8X
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:
    Align and Zip type-classes from the common Semialign ancestor.

description:
    The major use of @These@ of this is provided by the @align@ member of
    @Semialign@ class, representing a generalized notion of "zipping with padding"
    that combines structures without truncating to the size of the smaller input.

    It turns out that @zip@ operation fits well the @Semialign@ class,
    forming lattice-like structure.

category:             Data, These
abi:                  7dcc30bb1b4dfcca1873aa7877b031d7
exposed:              True
exposed-modules:
    Data.Align Data.Crosswalk Data.Semialign Data.Semialign.Indexed
    Data.Zip

hidden-modules:       Data.Semialign.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/semialign-1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/semialign-1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/semialign-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semialign
hs-libraries:         HSsemialign-1.3-BEOiTXTzJKR2MDDBEuAs8X
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-HayYj9uqgN4KUEsvzi6aVt
    indexed-traversable-0.1.4-92FdEpJkEfDIV3402POC6M
    indexed-traversable-instances-0.1.2-FFwXTdGZQwG7hsZo6zrZKG
    semigroupoids-6.0.1-CXyHMOvJM3yJpb1teCu7My
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    these-1.2.1-20Hlg0lYi8lImMgJCQDtWK transformers-0.5.6.2
    unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k
    vector-0.13.2.0-KVjnIHG2Fg91rA02TsgQOf

haddock-interfaces:   /usr/share/doc/haskell-semialign/html/semialign.haddock
haddock-html:         /usr/share/doc/haskell-semialign/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
